[−][src]Crate punch_clock
The punch-clock crate is a lightweight tool for tracking time.
This library exposes an API for performing all the same tasks as through the command-line interface (e.g. punching in or out, checking time tracking status, counting totals).
Re-exports
pub use sheet::Sheet; |
Modules
| sheet | Working with recorded timesheets (lists of events). |
Structs
| Event | Represents a (possibly ongoing) period of time tracking, with its associated metadata. |
Enums
| Period | Represents a period of time relative to now. |