Module sheet

Module sheet 

Working with recorded timesheets (lists of events).

Structs

Sheet
List of events, together comprising a log of work from which totals can be calculated for various periods of time.

Enums

SheetError
Errors arising through the use of Sheet.
SheetStatus
Whether or not time is currently being tracked.