[−][src]Enum punch_clock::sheet::SheetStatus
Whether or not time is currently being tracked.
Variants
Time is currently being tracked, and has been since the given instant.
Time is not currently being tracked, as of the given instant.
No time has ever been tracked.