Working with recorded timesheets (lists of events).
Structs
- Sheet
- List of events, together comprising a log of work from which totals can be calculated for various periods of time.
Enums
- Sheet
Error - Errors arising through the use of
Sheet. - Sheet
Status - Whether or not time is currently being tracked.